import { DatePicker } from "@mui/x-date-pickers";
import { dateToTime, timeToDate } from "../../utils/DateUtils";

export function DateInput(p: {
  ref?: React.Ref<HTMLInputElement>;
  editable?: boolean;
  autoFocus?: boolean;
  label?: string;
  style?: React.CSSProperties;
  value: number | undefined;
  onValueChange: (v: number | undefined) => void;
}): React.ReactElement {
  return (
    <DatePicker
      autoFocus={p.autoFocus}
      readOnly={p.editable === false}
      label={p.label}
      slotProps={{
        field: { ref: p.ref },
        textField: { variant: "standard", style: p.style },
      }}
      value={timeToDate(p.value)}
      onChange={(v) => {
        try {
          p.onValueChange(dateToTime(v ?? undefined));
        } catch (e) {
          console.warn("Failed to parse date!", e);
        }
      }}
    />
  );
}
